@@ -66,7 +66,8 @@ class RecordingsInformation:
         )
         if not resp:
             return None
-        elif "userQuotaMax" not in resp:
+
+        if "userQuotaMax" not in resp:
             _LOGGER.debug("D0010R - Recording data not found for %s", resp)
             return None
         return Quota(resp["userQuotaMax"], resp["userQuotaUsed"])
@@ -74,13 +75,13 @@ class RecordingsInformation:
     def book_recording(self, eid, series):
         """Book recording for specified item."""
         resp = None
-        if not series:
+        if series:
             resp = self._remote_config.device_access.retrieve_information(
-                REST_BOOK_RECORDING.format(eid), REST_POST
+                REST_BOOK_SERIES_RECORDING.format(eid), REST_POST
             )
         else:
             resp = self._remote_config.device_access.retrieve_information(
-                REST_BOOK_SERIES_RECORDING.format(eid), REST_POST
+                REST_BOOK_RECORDING.format(eid), REST_POST
             )
 
         if resp != RESPONSE_OK:
