@@ -54,6 +54,10 @@ REST_DELETE = "delete"
 # Sky specific constants
 CURRENT_URI = "CurrentURI"
 CURRENT_TRANSPORT_STATE = "CurrentTransportState"
+CURRENT_TRANSPORT_STATUS = "CurrentTransportStatus"
+CURRENT_SPEED = "CurrentSpeed"
+DEFAULT_TRANSPORT_STATE = "OK"
+DEFAULT_TRANSPORT_SPEED = 1
 APP_STATUS_VISIBLE = "VISIBLE"
 
 PVR = "pvr"
@@ -67,6 +71,7 @@ SKY_STATE_PAUSED = "PAUSED_PLAYBACK"
 SKY_STATE_STANDBY = "STANDBY"
 SKY_STATE_STOPPED = "STOPPED"
 SKY_STATE_TRANSITIONING = "TRANSITIONING"
+SKY_STATE_UNSUPPORTED = "UNSUPPORTED"
 SKY_STATUS_LIVE = "LIVE"
 
 APP_EPG = "com.bskyb.epgui"
@@ -139,3 +144,9 @@ ALLRECORDINGS = "all"
 REST_GET = "get"
 REST_POST = "post"
 REST_DELETE = "DELETE"
+
+DEVICE_GATEWAYSTB = "GATEWAYSTB"
+DEVICE_IPSETTOPBOX = "IPSETTOPBOX"
+DEVICE_MULTIROOMSTB = "MULTIROOMSTB"
+DEVICE_TV = "TV"
+UNSUPPORTED_DEVICES = [DEVICE_IPSETTOPBOX, DEVICE_TV]
