@@ -6,7 +6,7 @@ from datetime import datetime
 from .classes.app import AppInformation
 from .classes.channel import ChannelInformation
 from .classes.channelepg import ChannelEPGInformation
-from .classes.device import DeviceInformation
+from .classes.device import DeviceInformation, TransportInfo
 from .classes.deviceaccess import DeviceAccess
 from .classes.favourite import FavouriteInformation
 from .classes.media import MediaInformation
@@ -15,17 +15,13 @@ from .classes.recordings import RecordingsInformation
 from .const import (
     ALLRECORDINGS,
     COMMANDS,
-    CURRENT_TRANSPORT_STATE,
     EPG_ERROR_NO_DATA,
     EPG_ERROR_PAST_END,
-    SKY_STATE_NOMEDIA,
     SKY_STATE_OFF,
     SKY_STATE_ON,
-    SKY_STATE_PAUSED,
-    SKY_STATE_PLAYING,
     SKY_STATE_STANDBY,
-    SKY_STATE_STOPPED,
-    SKY_STATE_TRANSITIONING,
+    SKY_STATE_UNSUPPORTED,
+    UNSUPPORTED_DEVICES,
 )
 
 _LOGGER = logging.getLogger(__name__)
@@ -38,8 +34,8 @@ class SkyQRemote:
 
     def __init__(self, host, epg_cache_len=20, port=49160, json_port=9006):
         """Stand up a new SkyQ box."""
-        self.device_setup = False
-        self.gateway = False
+        self._device_setup = False
+        self._device_type = None
         self._host = host
         self._remote_country = None
         self._override_country = None
@@ -67,6 +63,16 @@ class SkyQRemote:
 
         self._setup_device()
 
+    @property
+    def device_setup(self):
+        """Get the dev ice setp state."""
+        return self._device_setup
+
+    @property
+    def device_type(self):
+        """Get the device type of the Sky Q box."""
+        return self._device_type
+
     def power_status(self) -> str:
         """Get the power status of the Sky Q box."""
         if not self._remote_country:
@@ -86,16 +92,10 @@ class SkyQRemote:
         if not self._remote_country:
             self._setup_remote()
 
-        response = self._device_information.get_transport_information()
-        if response is not None:
-            state = response[CURRENT_TRANSPORT_STATE]
-            if state in [SKY_STATE_NOMEDIA, SKY_STATE_STOPPED]:
-                return SKY_STATE_STANDBY
-            if state in [SKY_STATE_PLAYING, SKY_STATE_TRANSITIONING]:
-                return SKY_STATE_PLAYING
-            if state == SKY_STATE_PAUSED:
-                return SKY_STATE_PAUSED
-        return SKY_STATE_OFF
+        if self._device_type in UNSUPPORTED_DEVICES:
+            return TransportInfo(SKY_STATE_UNSUPPORTED, None, None)
+
+        return self._device_information.get_transport_information()
 
     def get_active_application(self):
         """Get the active application on Sky Q box."""
@@ -337,10 +337,10 @@ class SkyQRemote:
         if not device_info:
             return
 
-        if not self.device_setup:
+        if not self._device_setup:
             self._setup_device()
 
-        if not self._remote_country and self.device_setup:
+        if not self._remote_country and self._device_setup:
             skyq_country = self._import_country(
                 self._remote_config.device_info.used_country_code
             )
@@ -349,8 +349,8 @@ class SkyQRemote:
 
     def _setup_device(self):
 
-        self.device_setup = True
-        self.gateway = self._remote_config.device_info.gateway
+        self._device_setup = True
+        self._device_type = self._remote_config.device_info.deviceType
 
     def _import_country(self, country_code):
         """Work out the country for the Country Code."""
